#
# spec file for package qt6-location
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.8.2
%define short_version 6.8
%define tar_name qtlocation-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor docs%{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-location%{?pkg_suffix}
Version:        6.8.2
Release:        1.1
Summary:        Qt 6 Location plugins and libraries
License:        GPL-3.0-or-later
URL:            https://www.qt.io
Source0:        https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-location-rpmlintrc
BuildRequires:  qt6-core-private-devel
BuildRequires:  qt6-quick-private-devel
BuildRequires:  qt6-positioning-private-devel
BuildRequires:  qt6-positioningquick-private-devel
BuildRequires:  cmake(Qt6Core) = %{real_version}
BuildRequires:  cmake(Qt6QuickShapesPrivate) = %{real_version}
BuildRequires:  cmake(Qt6Gui) = %{real_version}
BuildRequires:  cmake(Qt6Network) = %{real_version}
BuildRequires:  cmake(Qt6Positioning) = %{real_version}
BuildRequires:  cmake(Qt6PositioningQuick) = %{real_version}
BuildRequires:  cmake(Qt6Qml) = %{real_version}
BuildRequires:  cmake(Qt6Quick) = %{real_version}
BuildRequires:  cmake(Qt6QuickTest) = %{real_version}
BuildRequires:  cmake(Qt6ShaderTools) = %{real_version}
BuildRequires:  cmake(Qt6Test) = %{real_version}
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%endif

%description
The Qt Location API helps creating mapping solutions using the data available
from some of the popular location services.

%if !%{qt6_docs_flavor}

%package -n libQt6Location6
Summary:        Qt 6 Location library

%description -n libQt6Location6
The Qt 6 Location library.

%package -n qt6-location-devel
Summary:        Qt 6 Location library - Development files
Requires:       libQt6Location6 = %{version}
Requires:       cmake(Qt6Gui) = %{real_version}
Requires:       cmake(Qt6Positioning) = %{real_version}
Requires:       cmake(Qt6PositioningQuick) = %{real_version}
Requires:       cmake(Qt6Qml) = %{real_version}
Requires:       cmake(Qt6Quick) = %{real_version}
Requires:       cmake(Qt6QuickShapesPrivate) = %{real_version}

%description -n qt6-location-devel
Development files for the Qt 6 Location library.

%package -n qt6-location-private-devel
Summary:        Non-ABI stable API for the Qt 6 Location Library
Requires:       cmake(Qt6Location) = %{real_version}

%description -n qt6-location-private-devel
This package provides private headers of libQt6Location that do not have any
ABI or API guarantees.

%{qt6_examples_package}

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6 \
  -DQT_GENERATE_SBOM:BOOL=FALSE

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

# CMake files are not needed for plugins
rm -r %{buildroot}%{_qt6_cmakedir}/Qt6Qml/QmlPlugins
rm %{buildroot}%{_qt6_cmakedir}/Qt6Location/*Plugin*.cmake

%ldconfig_scriptlets -n libQt6Location6

%files
%dir %{_qt6_pluginsdir}/geoservices
%{_qt6_pluginsdir}/geoservices/libqtgeoservices_itemsoverlay.so
%{_qt6_pluginsdir}/geoservices/libqtgeoservices_osm.so
%{_qt6_qmldir}/QtLocation/

%files -n libQt6Location6
%license LICENSES/*
%{_qt6_libdir}/libQt6Location.so.*

%files -n qt6-location-devel
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtLocationTestsConfig.cmake
%{_qt6_cmakedir}/Qt6Location/
%{_qt6_descriptionsdir}/Location.json
%{_qt6_includedir}/QtLocation/
%{_qt6_libdir}/libQt6Location.prl
%{_qt6_libdir}/libQt6Location.so
%{_qt6_metatypesdir}/qt6location_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_location.pri
%{_qt6_pkgconfigdir}/Qt6Location.pc
%exclude %{_qt6_includedir}/QtLocation/%{real_version}

%files -n qt6-location-private-devel
%{_qt6_includedir}/QtLocation/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_location_private.pri

%endif

%changelog
* Fri Jan 31 2025 Christophe Marin <christophe@krop.fr>
- Update to 6.8.2
  https://www.qt.io/blog/qt-6.8.2-released
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.1:
  * https://www.qt.io/blog/qt-6.8.1-released
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0:
  * https://www.qt.io/blog/qt-6.8-released
* Sat Sep 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.3
  * https://www.qt.io/blog/qt-6.7.3-released
* Wed Jun 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.2:
  * https://www.qt.io/blog/qt-6.7.2-released
* Tue May 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.1:
  * https://www.qt.io/blog/qt-6.7.1-released
* Tue Apr  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0:
  * https://www.qt.io/blog/qt-6.7-released
* Tue Mar 26 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.3:
  * https://www.qt.io/blog/qt-6.6.3-released
* Wed Feb 14 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.2
  * https://www.qt.io/blog/qt-6.6.2-released
* Mon Nov 27 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.1:
  * https://www.qt.io/blog/qt-6.6.1-released
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * https://www.qt.io/blog/qt-6.6-released
* Thu Sep 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.3
  * https://www.qt.io/blog/qt-6.5.3-released
* Thu Jul 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.2
  * https://www.qt.io/blog/qt-6.5.2-released-1
* Fri Jun 30 2023 Christophe Marin <christophe@krop.fr>
- Update subpackages requirements
* Wed May 24 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.1
  * https://www.qt.io/blog/qt-6.5.1-released
* Wed Apr  5 2023 Christophe Marin <christophe@krop.fr>
- Remove more CMake files related to plugins.
* Mon Apr  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * https://www.qt.io/blog/qt-6.5-lts-released
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Init qt6-location.
